@@ -52,14 +52,14 @@ class WebHDFS(object):
      
      
     def copyFromLocal(self, source_path, target_path, replication=1):
-        url_path = WEBHDFS_CONTEXT_ROOT + target_path + '?op=CREATE&overwrite=true&user.name='+self.username
+        url_path = WEBHDFS_CONTEXT_ROOT + "/" + target_path + '?op=CREATE&overwrite=true&user.name='+self.username
         
         httpClient = self.__getNameNodeHTTPClient()
         httpClient.request('PUT', url_path , headers={})
         response = httpClient.getresponse()
+        logger.debug("HTTP Response: %d, %s"%(response.status, response.reason))
         msg = response.msg
         redirect_location = msg["location"]
-        logger.debug("HTTP Response: %d, %s"%(response.status, response.reason))
         logger.debug("HTTP Location: %s"%(redirect_location))
         result = urlparse.urlparse(redirect_location)
         redirect_host = result.netloc[:result.netloc.index(":")]
@@ -80,7 +80,7 @@ class WebHDFS(object):
         
         
     def copyToLocal(self, source_path, target_path):
-        url_path = WEBHDFS_CONTEXT_ROOT + source_path+'?op=OPEN&overwrite=true&user.name='+self.username
+        url_path = WEBHDFS_CONTEXT_ROOT + "/" + source_path+'?op=OPEN&overwrite=true&user.name='+self.username
         logger.debug("GET URL: %s"%url_path)
         httpClient = self.__getNameNodeHTTPClient()
         httpClient.request('GET', url_path , headers={})
@@ -151,4 +151,4 @@ if __name__ == "__main__":
     webhdfs.listdir("/")
         
         
-        
\ No newline at end of file
+        
